@@ -1,7 +1,5 @@
 import os
-import sys
 COSMOBOOST_DIR = os.path.dirname(os.path.realpath(__file__))
-sys.path.insert(0, COSMOBOOST_DIR)
-from .cosmoboost import *
+#sys.path.insert(0, COSMOBOOST_DIR)
+from .blueprints import *
 from .lib.MatrixHandler import mL2indx
-
